@@ -3,7 +3,7 @@ import time
 
 from pathlib import Path
 
-from discogs_alert.client import UserTokenClient
+from discogs_alert.client import AnonClient, UserTokenClient
 from discogs_alert.notify import send_pushbullet_push
 from discogs_alert.utils import convert_currency, get_currency_rates, CONDITIONS
 
@@ -24,10 +24,11 @@ def loop(pushbullet_token, list_id, wantlist_path, user_agent, discogs_token, co
     msc = CONDITIONS[min_sleeve_condition]
 
     try:
-        client = UserTokenClient(user_agent, discogs_token)
+        client_anon = AnonClient(user_agent)
+        user_token_client = UserTokenClient(user_agent, discogs_token)
 
         if list_id is not None:
-            wantlist = client.get_list(list_id).get('items')
+            wantlist = user_token_client.get_list(list_id).get('items')
         else:
             wantlist = json.load(Path(wantlist_path).open('r'))
         for wanted_release in wantlist:
@@ -42,10 +43,10 @@ def loop(pushbullet_token, list_id, wantlist_path, user_agent, discogs_token, co
             price_threshold = wanted_release.get('price_threshold')
 
             valid_listings = []
-            release_stats = client.get_release_stats(release_id)
+            release_stats = user_token_client.get_release_stats(release_id)
             if release_stats:
                 if release_stats.get("num_for_sale") > 0 and not release_stats.get("blocked_from_sale"):
-                    for listing in client.get_marketplace_listings(release_id):
+                    for listing in client_anon.get_marketplace_listings(release_id):
 
                         # verify availability
                         if listing.get('availability') == f'Unavailable in {country}':
@@ -114,7 +115,7 @@ def loop(pushbullet_token, list_id, wantlist_path, user_agent, discogs_token, co
                 send_pushbullet_push(pushbullet_token, m_title, m_body, verbose=verbose)
 
     except Exception as e:
-        print(e)  # don't raise error (in case it's just temporary loss of internet connection)
+        print(e)  # don't raise error (in case it's just temporary loss of internet connection) – need better solution
 
     if verbose:
         print(f'\t took {time.time() - start_time}')
